@@ -115,12 +115,18 @@ class DBStore(TokenStore):
                     result = cursor.fetchone()
 
                     if result is not None:
-                        oauthtoken = OAuthToken(client_id=result[2], client_secret=result[3], grant_token=result[6],
-                                                 refresh_token=result[4], redirect_url=result[8])
+
+                        oauthtoken = token
                         oauthtoken.set_id(result[0])
-                        oauthtoken.set_access_token(result[5])
-                        oauthtoken.set_expires_in(str(result[7]))
                         oauthtoken.set_user_mail(result[1])
+                        oauthtoken.set_client_id(result[2])
+                        oauthtoken.set_client_secret(result[3])
+                        oauthtoken.set_refresh_token(result[4])
+                        oauthtoken.set_access_token(result[5])
+                        oauthtoken.set_grant_token(result[6])
+                        oauthtoken.set_expires_in(str(result[7]))
+                        oauthtoken.set_redirect_url(result[8])
+                        
                         return oauthtoken
 
             except Error as ex:
@@ -194,11 +200,12 @@ class DBStore(TokenStore):
 
                 for result in results:
 
-                    token = OAuthToken(client_id=result[2], client_secret=result[3], grant_token=result[6], refresh_token=result[4], redirect_url=result[8])
+                    token = OAuthToken(client_id=result[2], client_secret=result[3], refresh_token=result[4], grant_token=result[6])
                     token.set_id(result[0])
-                    token.set_expires_in(str(result[7]))
                     token.set_user_mail(result[1])
                     token.set_access_token(result[5])
+                    token.set_expires_in(str(result[7]))
+                    token.set_redirect_url(result[8])
                     tokens.append(token)
 
                 return tokens
@@ -248,11 +255,16 @@ class DBStore(TokenStore):
                     for result in results:
                         if result[0] == id:
 
-                            oauthtoken = OAuthToken(client_id=result[2], client_secret=result[3], grant_token=result[6], refresh_token=result[4], redirect_url=result[8])
                             oauthtoken.set_id(result[0])
-                            oauthtoken.set_access_token(result[5])
-                            oauthtoken.set_expires_in(str(result[7]))
                             oauthtoken.set_user_mail(result[1])
+                            oauthtoken.set_client_id(result[2])
+                            oauthtoken.set_client_secret(result[3])
+                            oauthtoken.set_refresh_token(result[4])
+                            oauthtoken.set_access_token(result[5])
+                            oauthtoken.set_grant_token(result[6])
+                            oauthtoken.set_expires_in(str(result[7]))
+                            oauthtoken.set_redirect_url(result[8])
+                            
                             return oauthtoken
 
             except Error as ex:
