@@ -12,6 +12,7 @@ from .info import Info
 from .convert_action_response import ConvertActionResponse
 from .convert_action_wrapper import ConvertActionWrapper
 from .body_wrapper import BodyWrapper
+from .tax import Tax
 from .consent import Consent
 from .lead_converter import LeadConverter
 from .convert_body_wrapper import ConvertBodyWrapper
@@ -47,7 +48,6 @@ from .file_handler import FileHandler
 from .deleted_records_handler import DeletedRecordsHandler
 from .mass_update_territory import MassUpdateTerritory
 from .mass_update_response_handler import MassUpdateResponseHandler
-from .inventory_line_items import InventoryLineItems
 from .carry_over_tags import CarryOverTags
 from .multi_select_picklist import MultiSelectPicklist
 from .response_wrapper import ResponseWrapper
