@@ -809,6 +809,10 @@ class Field(object):
 		def carrier(cls):
 			return Field('Carrier')
 
+		@classmethod
+		def quoted_items(cls):
+			return Field('Quoted_Items')
+
 		@classmethod
 		def quote_stage(cls):
 			return Field('Quote_Stage')
@@ -845,10 +849,6 @@ class Field(object):
 		def billing_code(cls):
 			return Field('Billing_Code')
 
-		@classmethod
-		def product_details(cls):
-			return Field('Product_Details')
-
 		@classmethod
 		def subject(cls):
 			return Field('Subject')
@@ -926,6 +926,10 @@ class Field(object):
 		def modified_by(cls):
 			return Field('Modified_By')
 
+		@classmethod
+		def invoiced_items(cls):
+			return Field('Invoiced_Items')
+
 		@classmethod
 		def billing_country(cls):
 			return Field('Billing_Country')
@@ -990,10 +994,6 @@ class Field(object):
 		def billing_code(cls):
 			return Field('Billing_Code')
 
-		@classmethod
-		def product_details(cls):
-			return Field('Product_Details')
-
 		@classmethod
 		def subject(cls):
 			return Field('Subject')
@@ -1189,6 +1189,10 @@ class Field(object):
 		def carrier(cls):
 			return Field('Carrier')
 
+		@classmethod
+		def ordered_items(cls):
+			return Field('Ordered_Items')
+
 		@classmethod
 		def quote_name(cls):
 			return Field('Quote_Name')
@@ -1237,10 +1241,6 @@ class Field(object):
 		def billing_code(cls):
 			return Field('Billing_Code')
 
-		@classmethod
-		def product_details(cls):
-			return Field('Product_Details')
-
 		@classmethod
 		def subject(cls):
 			return Field('Subject')
@@ -1725,6 +1725,10 @@ class Field(object):
 		def billing_country(cls):
 			return Field('Billing_Country')
 
+		@classmethod
+		def purchase_items(cls):
+			return Field('Purchase_Items')
+
 		@classmethod
 		def id(cls):
 			return Field('id')
@@ -1781,10 +1785,6 @@ class Field(object):
 		def billing_code(cls):
 			return Field('Billing_Code')
 
-		@classmethod
-		def product_details(cls):
-			return Field('Product_Details')
-
 		@classmethod
 		def subject(cls):
 			return Field('Subject')
