@@ -19,6 +19,8 @@ class Constants(object):
 
     REQUEST_METHOD_DELETE = "DELETE"
 
+    GIVEN_VALUE = "given-value"
+
     REQUEST_METHOD_PATCH = 'PATCH'
 
     OAUTH_HEADER_PREFIX = "Zoho-oauthtoken "
@@ -27,8 +29,99 @@ class Constants(object):
 
     API_NAME = "api_name"
 
+    PHOTO = "photo"
+
+    API_VERSION = "v2.1"
+
+    CRM = "crm"
+
+    INPUT_ERROR = "INPUT_ERROR"
+
+    LOGGER_LEVELS = {
+        "CRITICAL": "CRITICAL",
+        "ERROR": "ERROR",
+        "WARNING": "WARNING",
+        "INFO": "INFO",
+        "DEBUG": "DEBUG",
+        "NOTSET": "NOTSET"
+    }
+    INVENTORY_MODULES_ITEMS = ["invoiced_items", "quoted_items","purchase_items","ordered_items"]
+      
+
+    DEFAULT_MODULENAME_VS_APINAME = {
+
+        "leads": "Leads",
+
+        "contacts": "Contacts",
+
+        "accounts": "Accounts",
+
+        "deals": "Deals",
+
+        "tasks": "Tasks",
+
+        "events": "Events",
+
+        "activities": "Activities",
+
+        "calls": "Calls",
+
+        "products": "Products",
+
+        "quotes": "Quotes",
+
+        "sales_orders": "Sales_Orders",
+
+        "purchase_orders": "Purchase_Orders",
+
+        "invoices": "Invoices",
+
+        "campaigns": "Campaigns",
+
+        "vendors": "Vendors",
+
+        "price_books": "Price_Books",
+
+        "cases": "Cases",
+
+        "solutions": "Solutions",
+
+        "visits": "Visits",
+
+        "approvals": "Approvals",
+
+        "notes": "Notes",
+
+        "attachments": "Attachments",
+
+        "actions_performed": "Actions_Performed",
+
+    }
+
+    PROXY_SETTINGS = "Proxy settings - "
+
+    PROXY_HOST = "Host: "
+
+    PROXY_PORT = "Port: "
+
+    PROXY_USER = "User: "
+
+    PROXY_DOMAIN = "Domain: "
+
+    GET_TOKEN_BY_ID_DB_ERROR = "Exception in getTokenById - DBStore : Given ID is invalid"
+
+    GET_TOKEN_BY_ID_FILE_ERROR = "Exception in getTokenById - FileStore : Given ID is invalid"
+
+    MYSQL_TABLE_NAME = "oauthtoken"
+
+    SWITCH_USER_ERROR = "SWITCH USER ERROR"
+
+    LOGGER_INITIALIZATION_ERROR = "Exception in Logger Initialization : "
+
     INVALID_ID_MSG = "The given id seems to be invalid."
 
+    RESOURCE_PATH_INVALID_ERROR_MESSAGE = "Resource Path MUST be a valid directory."
+
     API_MAX_RECORDS_MSG = "Cannot process more than 100 records at a time."
 
     INVALID_DATA = "INVALID_DATA"
@@ -55,9 +148,13 @@ class Constants(object):
 
     CLIENT_SECRET = "client_secret"
 
-    REDIRECT_URL = "redirect_uri"
+    REDIRECT_URI = "redirect_uri"
 
-    TYPE_VS_DATATYPE = {
+    REDIRECT_URL = "redirect_url"
+
+    OBJECT = "Object"
+
+    DATA_TYPE = {
         "String": str,
         "List": list,
         "Integer": int,
@@ -73,11 +170,13 @@ class Constants(object):
 
     OBJECT_KEY = "object"
 
+    PHOTO_SUPPORTED_MODULES = ["Leads", "Contacts", "Accounts", "Products", "Vendors", "Deals", "Cases", "Solutions"]
+
     GIVEN_LENGTH = "given-length"
 
     ZOHO_SDK = "X-ZOHO-SDK"
 
-    SDK_VERSION = "3.1.0"
+    SDK_VERSION = "4.0.0"
 
     CONTENT_DISPOSITION = "Content-Disposition"
 
@@ -219,8 +318,20 @@ class Constants(object):
 
     LINE_TAX_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.LineTax"
 
+    TAX_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Tax"
+
+    PRODUCTS = "Products"
+
+    TAX = "TAX"
+
+    TERRITORY = "Territory"
+
     REMINDER_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Reminder"
 
+    TERRITORY_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Territory"
+
+    IMAGEUPLOAD_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.ImageUpload"
+
     ATTACHMENTS_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.attachments.Attachment"
 
     RECURRING_ACTIVITY_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.RecurringActivity"
@@ -253,6 +364,14 @@ class Constants(object):
 
     EXPECTED_TYPE = "expected-type"
 
+    USER_AGENT = "Mozilla/5.0"
+
+    USER_AGENT_KEY = "user-agent"
+
+    AT = '@'
+
+    EXPECTED_TOKEN_TYPES = 'REFRESH, GRANT'
+
     INITIALIZATION_ERROR = "INITIALIZATION ERROR"
 
     ENVIRONMENT = "environment"
@@ -269,7 +388,7 @@ class Constants(object):
 
     EMAIL = "email"
 
-    USER_SIGNATURE_ERROR = "USERSIGNATURE ERROR";
+    USER_SIGNATURE_ERROR = "USERSIGNATURE ERROR"
 
     USER_INITIALIZATION_ERROR = "Error during User Initialization"
 
@@ -299,6 +418,10 @@ class Constants(object):
 
     DATETIME_NAMESPACE = 'DateTime'
 
+    DISCOUNT = "DISCOUNT"
+
+    LINEITEM_PRODUCT = "zcrmsdk.src.com.zoho.crm.api.record.LineItemProduct"
+
     FILE_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.util.StreamWrapper"
 
     KEYS_TO_SKIP = ['Created_Time', 'Modified_Time', 'Created_By', 'Modified_By', 'Tag']
@@ -377,7 +500,7 @@ class Constants(object):
 
     RESOURCE_PATH_ERROR_MESSAGE = "Resource Path MUST NOT be None/empty."
 
-    SET_TO_CONTENT_TYPE = ["/crm/bulk/v2/read", "/crm/bulk/v2/write"]
+    SET_CONTENT_TYPE_HEADER = ["/crm/bulk/v2.1/read", "/crm/bulk/v2.1/write"]
 
     CONTENT_TYPE_HEADER = "Content-Type"
 
@@ -387,6 +510,30 @@ class Constants(object):
 
     FILE_ID = "file_id"
 
+    PHOTO_UPLOAD_ERROR_MESSAGE = "The given module is not supported in API."
+
+    INVALID_MODULE = "INVALID_MODULE"
+
+    MULTI_SELECT_LOOKUP = "multiselectlookup"
+
+    MULTI_USER_LOOKUP = "multiuserlookup"
+
+    TERRITORIES = "territories"
+
+    GENERATED_TYPE = "generated_type"
+
+    GENERATED_TYPE_CUSTOM = "custom"
+
+    UPLOAD_PHOTO_UNSUPPORTED_MESSAGE = "Photo Upload Operation is not supported by the module: "
+
+    SDK_MODULE_METADATA = "SDK-MODULE-METADATA"
+
+    INVALID_MODULE_API_NAME_ERROR = "INVALID MODULE API NAME ERROR"
+
+    PROVIDE_VALID_MODULE_API_NAME = "PROVIDE VALID MODULE API NAME: "
+
+    UPLOAD_PHOTO_UNSUPPORTED_ERROR = "UPLOAD PHOTO UNSUPPORTED MODULE"
+
     DELETE_FIELD_FILE_ERROR = "Exception in deleting Current User Fields file : "
 
     DELETE_FIELD_FILES_ERROR = "Exception in deleting all Fields files : "
@@ -469,6 +616,8 @@ class Constants(object):
 
     HEADER_NONE_ERROR = "NONE HEADER ERROR"
 
+    PRODUCT_NAME = "Product_Name"
+
     HEADER_INSTANCE_NONE_ERROR = "Header Instance MUST NOT be None"
 
     PARAM_INSTANCE_NONE_ERROR = "Param Instance MUST NOT be None"
@@ -485,8 +634,6 @@ class Constants(object):
 
     PARAM_NAME_NONE_ERROR_MESSAGE = "Param Name MUST NOT be None"
 
-    SWITCH_USER_ERROR = "SWITCH USER ERROR"
-
     USER_PROXY_ERROR = "USERPROXY ERROR"
 
     HOST_ERROR_MESSAGE = "Host MUST NOT be None"
@@ -505,14 +652,6 @@ class Constants(object):
 
     ATTACHMENTS = "$attachments"
 
-    PROXY_SETTINGS = "Proxy settings - "
-
-    PROXY_HOST = "Host: "
-
-    PROXY_PORT = "Port: "
-
-    PROXY_USER = "User: "
-
     JSON_FILE_EXTENSION = ".json"
 
     FILE_ERROR = "file_error"
@@ -526,3 +665,23 @@ class Constants(object):
     USER_MAIL_NULL_ERROR_MESSAGE = "User Mail MUST NOT be None. Set value to user_mail."
 
     JSON_DETAILS_ERROR = "ERROR IN READING JSONDETAILS FILE"
+
+    INVALID_TOKEN_ERROR = "INVALID TOKEN ERROR"
+
+    NO_ACCESS_TOKEN_ERROR = "ACCESS TOKEN IS NOT PRESENT IN RESPONSE"
+
+    CLIENT_ID_NULL_ERROR_MESSAGE = "ClientID MUST NOT be null"
+
+    CLIENT_SECRET_NULL_ERROR_MESSAGE = "ClientSecret MUST NOT be null"
+
+    REQUEST_PROXY_ERROR_MESSAGE = "request_proxy must be instance of Request Proxy"
+
+    USER_SIGNATURE_ERROR_MESSAGE = "user must be instance of userSignature."
+
+    ENVIRONMENT_ERROR_MESSAGE = "environment must be instance of Environment."
+
+    SDK_CONFIG_ERROR_MESSAGE = "sdk_config must be instance of sdkConfig."
+
+    TOKEN_ERROR_MESSAGE = "token must be instance of Token."
+
+    STORE_ERROR_MESSAGE = "store must be instance of Store."
